==> haskell-with-utf8-1.0.2.2-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 with-utf8
version:              1.0.2.2
visibility:           public
id:                   with-utf8-1.0.2.2-IHDofrTOU7iKf0MktPaRKU
key:                  with-utf8-1.0.2.2-IHDofrTOU7iKf0MktPaRKU
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  ad36070ae811b71ca56d8b939b01edb0
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-8.10.4/site-local/with-utf8-1.0.2.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/with-utf8-1.0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/with-utf8-1.0.2.2
hs-libraries:         HSwith-utf8-1.0.2.2-IHDofrTOU7iKf0MktPaRKU
depends:
    base-4.14.1.0 safe-exceptions-0.1.7.1-7RLV3SXk3Vv3Qe74BGZQg3
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-with-utf8-1.0.2.2-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 with-utf8
version:              1.0.2.2
visibility:           public
id:                   with-utf8-1.0.2.2-1zmZN6bQUAz8PFb93NdMxV
key:                  with-utf8-1.0.2.2-1zmZN6bQUAz8PFb93NdMxV
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  2364ac1fe5ef81b09e95999174e23e52
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-8.10.4/site-local/with-utf8-1.0.2.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/with-utf8-1.0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/with-utf8-1.0.2.2
hs-libraries:         HSwith-utf8-1.0.2.2-1zmZN6bQUAz8PFb93NdMxV
depends:
    base-4.14.1.0 safe-exceptions-0.1.7.1-2w7aqd118RZ8sxN9lvp2D0
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
